summaryrefslogtreecommitdiff
path: root/src/mongo/db/query/internal_plans.h
diff options
context:
space:
mode:
authorMathias Stearn <mathias@10gen.com>2014-11-26 15:04:26 -0500
committerMathias Stearn <mathias@10gen.com>2014-11-26 15:15:59 -0500
commit16a8ef7ad60d498b69bdc0ad5cbca44757d16fd8 (patch)
tree2d9f056acf8f1b9b2e943f82e315bdf019475a38 /src/mongo/db/query/internal_plans.h
parentcb5cab88761d9aca75e064665cce89f579c69e36 (diff)
downloadmongo-16a8ef7ad60d498b69bdc0ad5cbca44757d16fd8.tar.gz
SERVER-13679 Replace DiskLoc with RecordId outside of MMAPv1
Operations: sed -i -e 's/\<DiskLoc\>/RecordId/g' sed -i -e 's/\<DiskLocs\>/RecordIds/g' sed -i -e 's/\<minDiskLoc\>/RecordId::min()/g' sed -i -e 's/\<maxDiskLoc\>/RecordId::max()/g' sed -i -e 's/\<getDiskLoc\>/getRecordId/g'' Changes under mmap_v1 were reverted and redone by hand as needed.
Diffstat (limited to 'src/mongo/db/query/internal_plans.h')
-rw-r--r--src/mongo/db/query/internal_plans.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mongo/db/query/internal_plans.h b/src/mongo/db/query/internal_plans.h
index 88c27b8132b..5f992a65b73 100644
--- a/src/mongo/db/query/internal_plans.h
+++ b/src/mongo/db/query/internal_plans.h
@@ -53,10 +53,10 @@ namespace mongo {
enum IndexScanOptions {
// The client is interested in the default outputs of an index scan: BSONObj of the key,
// DiskLoc of the record that's indexed. The client does its own fetching if required.
IXSCAN_DEFAULT = 0,
// The client wants the fetched object and the DiskLoc that refers to it. Delegating
// the fetch to the runner allows fetching outside of a lock.
IXSCAN_FETCH = 1,
};
@@ -68,7 +68,7 @@ namespace mongo {
const StringData& ns,
Collection* collection,
const Direction direction = FORWARD,
- const DiskLoc startLoc = DiskLoc()) {
+ const RecordId startLoc = RecordId()) {
WorkingSet* ws = new WorkingSet();
if (NULL == collection) {
@@ -53,10 +53,10 @@ namespace mongo {
enum IndexScanOptions {
// The client is interested in the default outputs of an index scan: BSONObj of the key,
- // DiskLoc of the record that's indexed. The client does its own fetching if required.
+ // RecordId of the record that's indexed. The client does its own fetching if required.
IXSCAN_DEFAULT = 0,
@@ -53,10 +53,10 @@ namespace mongo {
IXSCAN_DEFAULT = 0,
- // The client wants the fetched object and the DiskLoc that refers to it. Delegating
+ // The client wants the fetched object and the RecordId that refers to it. Delegating
// the fetch to the runner allows fetching outside of a lock.
IXSCAN_FETCH = 1,